@@ -832,18 +832,22 @@ static PyObject *_wrap_gnome_dentry_edit_save_file(PyObject *self, PyObject *arg
 }
 
 static PyObject *_wrap_gnome_dialog_button_connect(PyObject *self, PyObject *args) {
-  PyObject *obj, *callback, * extra, * data;
+  PyObject *obj, *callback, *extra, *data;
   int button;
 
-  if (!PyArg_ParseTuple(args, "O!iO:gnome_dialog_button_connect", &PyGtk_Type,
-			&obj, &button, &callback))
+  if (!PyArg_ParseTuple(args, "O!iO|O!:gnome_dialog_button_connect",
+			&PyGtk_Type, &obj, &button, &callback,
+			&PyTuple_Type, &extra))
     return NULL;
   if (!PyCallable_Check(callback)) {
     PyErr_SetString(PyExc_TypeError, "third argument not callable");
     return NULL;
   }
 
-  extra = PyTuple_New(0);
+  if (extra)
+    Py_INCREF(extra);
+  else
+    extra = PyTuple_New(0);
 
   if (extra == NULL)
     return NULL;
@@ -910,6 +914,8 @@ static PyObject *_wrap_gnome_icon_list_get_icon_data(PyObject *self, PyObject *a
 			&PyGtk_Type, &ilist, &pos))
     return NULL;
   data = gnome_icon_list_get_icon_data(GNOME_ICON_LIST(PyGtk_Get(ilist)), pos);
+  if (data == NULL)
+    data = Py_None;
   Py_INCREF(data);
   return data;
 }
